import { InputWrapper } from "@/components/fields/Fields";
import FormComponent from "@/components/form/Form";
import { Button, FormControl, FormLabel, Modal, ModalBody, ModalCloseButton, ModalContent, ModalFooter, ModalHeader, ModalOverlay, Text, useColorModeValue } from "@chakra-ui/react";
import { useRef, useEffect, useState } from "react";
import prepareValidationSchema from "@/utils/validation-schema";
import { formFields } from "../variables/formFields";
import { IbcInterface } from "@/types/settings/ibc/ibc";

interface IbcModalFormProps {
    isOpen: boolean;
    onClose: () => void;
    currentUser: IbcInterface | null;
    handleSubmit: (values: any) => Promise<void>;
}

const IbcModalForm: React.FC<IbcModalFormProps> = ({ isOpen, onClose, currentUser, handleSubmit }) => {
    const formRef = useRef(null);
    const textColor = useColorModeValue("navy.700", "white");
    const brandStars = useColorModeValue("brand.500", "brand.400");

    const formDetails = prepareValidationSchema(formFields);
    const { initialFormData, validationSchema } = formDetails;

    // Set initial values based on whether we are adding or editing
    const initialValues = currentUser ? { ...currentUser } : initialFormData;

    const handleSubmitClick = () => {
        formRef?.current?.externalHandleSubmit();
    };

    return (
        <Modal onClose={onClose} size="lg" isOpen={isOpen}>
            <ModalOverlay />
            <ModalContent>
                <ModalHeader>{currentUser ? "Edit" : "Create"} Ibc</ModalHeader>
                <ModalCloseButton />
                <ModalBody>
                    <FormComponent
                        ref={formRef}
                        validationSchema={validationSchema}
                        initialValues={initialValues}
                        // enableReinitialize // Ensures the form reinitializes with updated initial values
                        submitForm={handleSubmit}
                    >
                        <FormControl w="full">
                            <FormLabel fontSize="sm" fontWeight="500" color={textColor} mb="8px">
                                Area Name
                                <Text color={brandStars}>*</Text>
                            </FormLabel>
                            <InputWrapper
                                form
                                fieldName="area_name"
                                defaultValue={currentUser?.area_name}
                                id="area_name"
                                variant="auth"
                                w="full"
                                mb="2px"
                                fontSize="sm"
                                type="text"
                                fontWeight="500"
                            />
                        </FormControl>
                        <FormControl w="full">
                            <FormLabel fontSize="sm" fontWeight="500" color={textColor} mb="8px">
                                IBC Code
                                <Text color={brandStars}>*</Text>
                            </FormLabel>
                            <InputWrapper
                                form
                                fieldName="ibc_code"
                                defaultValue={currentUser?.ibc_code}
                                id="ibc_code"
                                variant="auth"
                                w="full"
                                mb="2px"
                                fontSize="sm"
                                type="number"
                                fontWeight="500"
                            />
                        </FormControl>
                    </FormComponent>
                </ModalBody>
                <ModalFooter>
                    <Button variant="brand" onClick={handleSubmitClick} mr={3}>
                        {currentUser ? "Save" : "Create"}
                    </Button>
                    <Button onClick={onClose}>Cancel</Button>
                </ModalFooter>
            </ModalContent>
        </Modal>
    );
};

export default IbcModalForm;
